Package: RoughSets
Maintainer: Christoph Bergmeir <c.bergmeir@decsai.ugr.es>
License: GPL (>= 2)
Encoding: UTF-8
Title: Data Analysis Using Rough Set and Fuzzy Rough Set Theories
Authors@R: c(person("Andrzej", "Janusz", role = "aut",
                    email = "janusza@mimuw.edu.pl"),
             person("Lala Septem", "Riza", role = "aut",
                     email = "lala_s_riza@yahoo.com"),
             person("Dominik", "Ślęzak", role = "ctb"),
             person("Chris", "Cornelis", role = "ctb"),
             person("Francisco", "Herrera", role = "ctb"),
             person("Jose Manuel", "Benitez", role = "ctb"),
             person("Christoph", "Bergmeir", role = c("ctb", "cre"),
                    email = "c.bergmeir@decsai.ugr.es"),
             person("Sebastian", "Stawicki", role = "ctb"))
Description: Implementations of algorithms for data analysis based on the
    rough set theory (RST) and the fuzzy rough set theory (FRST). We not only
    provide implementations for the basic concepts of RST and FRST but also
    popular algorithms that derive from those theories. The methods included in the
    package can be divided into several categories based on their functionality:
    discretization, feature selection, instance selection, rule induction and
    classification based on nearest neighbors. RST was introduced by Zdzisław
    Pawlak in 1982 as a sophisticated mathematical tool to model and process
    imprecise or incomplete information. By using the indiscernibility relation for
    objects/instances, RST does not require additional parameters to analyze the
    data. FRST is an extension of RST. The FRST combines concepts of vagueness and
    indiscernibility that are expressed with fuzzy sets (as proposed by Zadeh, in
    1965) and RST.
Version: 1.3-8
URL: https://github.com/janusza/RoughSets
Date: 2024-01-23
Suggests: class
LinkingTo: Rcpp
Depends: Rcpp
RoxygenNote: 7.2.3
NeedsCompilation: yes
Packaged: 2024-01-23 07:49:16 UTC; bergmeir
Author: Andrzej Janusz [aut],
  Lala Septem Riza [aut],
  Dominik Ślęzak [ctb],
  Chris Cornelis [ctb],
  Francisco Herrera [ctb],
  Jose Manuel Benitez [ctb],
  Christoph Bergmeir [ctb, cre],
  Sebastian Stawicki [ctb]
Repository: CRAN
Date/Publication: 2024-01-23 10:12:47 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-27 02:15:48 UTC; unix
Archs: RoughSets.so.dSYM
