# Generated by roxygen2: do not edit by hand

S3method("[",RuleSetRST)
S3method(as.character,RuleSetRST)
S3method(as.list,RuleSetRST)
S3method(predict,RuleSetFRST)
S3method(predict,RuleSetRST)
S3method(print,FeatureSubset)
S3method(print,RuleSetRST)
S3method(summary,IndiscernibilityRelation)
S3method(summary,LowerUpperApproximation)
S3method(summary,PositiveRegion)
S3method(summary,RuleSetFRST)
S3method(summary,RuleSetRST)
export(BC.IND.relation.FRST)
export(BC.IND.relation.RST)
export(BC.LU.approximation.FRST)
export(BC.LU.approximation.RST)
export(BC.boundary.reg.RST)
export(BC.discernibility.mat.FRST)
export(BC.discernibility.mat.RST)
export(BC.negative.reg.RST)
export(BC.positive.reg.FRST)
export(BC.positive.reg.RST)
export(C.FRNN.FRST)
export(C.FRNN.O.FRST)
export(C.POSNN.FRST)
export(D.discretization.RST)
export(D.discretize.equal.intervals.RST)
export(D.discretize.quantiles.RST)
export(D.global.discernibility.heuristic.RST)
export(D.local.discernibility.heuristic.RST)
export(FS.DAAR.heuristic.RST)
export(FS.all.reducts.computation)
export(FS.feature.subset.computation)
export(FS.greedy.heuristic.reduct.RST)
export(FS.greedy.heuristic.superreduct.RST)
export(FS.nearOpt.fvprs.FRST)
export(FS.one.reduct.computation)
export(FS.permutation.heuristic.reduct.RST)
export(FS.quickreduct.FRST)
export(FS.quickreduct.RST)
export(FS.reduct.computation)
export(IS.FRIS.FRST)
export(IS.FRPS.FRST)
export(MV.conceptClosestFit)
export(MV.deletionCases)
export(MV.globalClosestFit)
export(MV.missingValueCompletion)
export(MV.mostCommonVal)
export(MV.mostCommonValResConcept)
export(RI.AQRules.RST)
export(RI.CN2Rules.RST)
export(RI.GFRS.FRST)
export(RI.LEM2Rules.RST)
export(RI.confidence)
export(RI.hybridFS.FRST)
export(RI.indiscernibilityBasedRules.RST)
export(RI.laplace)
export(RI.lift)
export(RI.support)
export(SF.applyDecTable)
export(SF.asDecisionTable)
export(SF.asFeatureSubset)
export(SF.read.DecisionTable)
export(X.entropy)
export(X.gini)
export(X.laplace)
export(X.nOfConflicts)
export(X.ruleStrength)
export(X.rulesCounting)
import(Rcpp)
useDynLib(RoughSets, .registration = TRUE)
